﻿using Connected.Classes.Grid;
using Connected.Utilities;
using Microsoft.AspNetCore.Components;
using Microsoft.Extensions.Options;
using System.Collections.ObjectModel;

namespace Connected.Components;
public partial class Grid<DataType> : ComponentBase
{

	[Parameter]
	public ObservableCollection<DataType>? Items { get; set; }

	private List<DataType>? ItemsToShow { get; set; }

	[Parameter]
	public RenderFragment<DataType>? RowTemplate { get; set; }

	[Parameter]
	public RenderFragment<DataType>? RowDetailTemplate { get; set; }
	[Parameter]
	public RenderFragment? Img { get; set; }

	[Parameter]
	public DataGridOptions? Options { get; set; } = null;

	[Parameter]
	public List<string>? SearchFilters { get; set; } = null;

	public int Count
	{
		get
		{
			return Items?.Count ?? 0;
		}
	}

	[Parameter]
	public string GridClass { get; set; } = string.Empty;
	private CssBuilder GridClassList
	{
		get
		{
			return new CssBuilder("data-grid")
				.AddClass("dense", Options?.Dense ?? true)
				.AddClass("image", Options?.ShowImage ?? true)
				.AddClass("select", Options?.ShowSelect ?? true)
				.AddClass("collapse", Options?.Collapsible ?? true)
				.AddClass(GridClass);
		}
	}

	public void GetItems()
	{
		/*
		 Web API call for item fetch include SearchFilters
		 */
		SetItemsToShow();
	}

	private void OnPageChange(int page)
	{
		Options.SelectedPage=page;
		
		//SetItemsToShow();
	}

	private void SetItemsToShow()
	{
		ItemsToShow=  Items?.Skip(Options.Offset).Take(Options.ItemsPerPage).ToList() ?? new();
	}

	protected override async Task OnInitializedAsync()
	{
		SetItemsToShow();
		await base.OnInitializedAsync();
	}
}
