﻿using Connected.Utilities;
using Microsoft.AspNetCore.Components;

namespace Connected.Components;
public partial class GridRow<DataType> : ComponentBase
{

	[CascadingParameter]
	public Grid<DataType> Parent { get; set; }

	[Parameter]
	public RenderFragment<DataType>? FixedContent { get; set; }

	[Parameter]
	public RenderFragment<DataType>? CollapsibleContent { get; set; }

	[Parameter]
	public string? ImgSrc { get; set; } = null;

	[Parameter]
	public DataType? Item { get; set; }

	[Parameter]
	public bool CollapsedItemShown { get; set; } = false;

	private void ToggleNav()
	{
		CollapsedItemShown = !CollapsedItemShown;
	}

	[Parameter]
	public string RowClass { get; set; } = string.Empty;
	private CssBuilder GridRowClass
	{
		get
		{
			return new CssBuilder("data-grid-row-content")
				.AddClass("show", CollapsedItemShown)
				.AddClass(RowClass);
		}
	}

	private CssBuilder CollapsedClass
	{
		get
		{
			return new CssBuilder()
				.AddClass("show", CollapsedItemShown)
				.AddClass(RowClass);
		}
	}

	private bool ShowImageBlock()
	{
		if (string.IsNullOrEmpty(ImgSrc)) return false;
		bool result = Parent.Options?.ShowImage ?? true;
		return result;
	}

	private CssBuilder ImageClass
	{
		get
		{
			return new CssBuilder()
				.AddClass("show-image-vertical", Parent.Options.ImagePosition==SmScrn_GridImgPos.Top)
				.AddClass("show-image", Parent.Options.ImagePosition == SmScrn_GridImgPos.Left)

				.AddClass(RowClass);
		}
	}

	[Parameter]
	public EventCallback<ChangeEventArgs> SwitchButtonChangeEvent { get; set; }

	private async Task SwitchButtonChange(ChangeEventArgs args)
	{
		await SwitchButtonChangeEvent.InvokeAsync(args);
	}

	private void SetImgSrc()
	{
		var colname = Parent.Options.DataSet_ImgColName;
		var property = typeof(DataType).GetProperty(colname);
		ImgSrc = property?.GetValue(Item)?.ToString() ?? "";
	}

	protected override async Task OnInitializedAsync()
	{
		SetImgSrc();
		await base.OnInitializedAsync();
	}

	private string SwitchButtonId = Guid.NewGuid().ToString();

}